@@ -2,20 +2,22 @@ var React = require('react')
 var ReactDOM = require('react-dom')
 var prettyBytes = require('pretty-bytes')
 var EditInPlace = require('react-editinplace')
+var prettyBytes = require('pretty-bytes')
 
+var api = require('../api')
 var xhr = require('../request.js')
 
+var DownloadButton = React.createClass({
+  render: function () {
+    var href = '/download/' + this.props.dat
+    return <a href={href} className='green waves-effect waves-light btn'>Download</a>
+  }
+})
+
 var DeleteButton = React.createClass({
   delete: function () {
     var self = this
-    var opts = {
-      uri: '/dats',
-      method: 'DELETE',
-      json: {
-        key: this.props.dat
-      }
-    }
-    xhr(opts, function (resp, json) {
+    api.delete(this.props.dat, function (err, resp, json) {
       render()
     })
   },
@@ -26,11 +28,19 @@ var DeleteButton = React.createClass({
 
 var ListItem = React.createClass({
   render: function () {
+    var health = this.props.dat.health
     return (
       <div className='section list-item' onClick={this.handleClick}>
-        <p>{this.props.dat}</p>
+        <p>{this.props.dat.key}</p>
+        <p>
+          {prettyBytes(health.byteLength)}
+        </p>
+        <p>
+          {health.peers.length} peers
+        </p>
         <div>
-          <DeleteButton dat={this.props.dat} />
+          <DeleteButton dat={this.props.dat.key} />
+          <DownloadButton dat={this.props.dat.key} />
         </div>
       </div>
     )
@@ -41,8 +51,8 @@ var List = React.createClass({
   render: function () {
     return (
       <div>
-        {this.props.dats.map(function (key) {
-          return <ListItem dat={key} key={key} />
+        {this.props.dats.map(function (dat) {
+          return <ListItem dat={dat} key={dat.key} />
         })}
       </div>
     )
@@ -52,15 +62,12 @@ var List = React.createClass({
 module.exports = render
 
 function render (cb) {
-  xhr({uri: '/dats', json: true}, function (resp, json) {
-    if (cb) cb(json)
-    _render(json)
+  api.list(function (err, dats) {
+    if (cb) cb(dats)
+    if (!dats) dats = []
+    ReactDOM.render(
+      <List dats={dats} />,
+      document.getElementById('app')
+    )
   })
 }
-
-function _render (dats) {
-  ReactDOM.render(
-    <List dats={dats} />,
-    document.getElementById('app')
-  )
-}
