@@ -1,4 +1,5 @@
-var xhr = require('./request')
+var api = require('./api')
+var status = require('./components/status')
 var renderList = require('./components/list')
 
 var $link = document.getElementById('link')
@@ -7,16 +8,12 @@ var $loading = document.getElementById('loading')
 document.getElementById('submit').onclick = submit
 
 function submit (event) {
-  var opts = {
-    method: 'POST',
-    uri: '/dats',
-    json: {
-      key: $link.value.trim()
-    }
-  }
+  var key = $link.value.trim()
   $link.value = ''
   $loading.style = 'display:block;'
-  xhr(opts, function (resp, json) {
+  api.add(key, function (err) {
+    if (err) status(err.message)
+    else status('Dat added successfully.')
     renderList()
     $loading.style = 'display:none;'
   })
